@@ -224,6 +224,10 @@ class TuneTheModel():
         self._model_type = model_type
         self._name = kwargs["name"] if "name" in kwargs else None
 
+    @property
+    def name(self):
+        return self._name
+
     @classmethod
     def from_dict(cls, model: dict) -> 'TuneTheModel':
         return cls(**model)
@@ -267,6 +271,14 @@ class TuneTheModel():
             cls.from_dict(data) for data in r.get("models", [])
         ]
 
+    @classmethod
+    def public_models(cls) -> List["TuneTheModel"]:
+        r = TuneTheModelAPI.public_models()
+
+        return [
+            cls.from_dict(data) for data in r.get("models", [])
+        ]
+
     @classmethod
     def load_model(cls, filename: str) -> 'TuneTheModel':
         if os.path.isfile(filename):
